import { z } from 'zod';
import { config as loadDotenv } from 'dotenv';
loadDotenv();
const Schema = z.object({
    NODE_ENV: z.enum(['development', 'test', 'production']).default('development'),
    CONTROL_PLANE_PORT: z.coerce.number().int().positive().default(8080),
    CONTROL_PLANE_PUBLIC_URL: z.string().url().default('http://localhost:8080'),
    DATABASE_URL: z.string().min(1).optional(),
    REDIS_URL: z.string().min(1).default('redis://127.0.0.1:6379'),
    JWT_SECRET: z.string().min(16).default('change_me_change_me_change_me_now'),
    LOG_LEVEL: z.enum(['fatal', 'error', 'warn', 'info', 'debug', 'trace']).default('info'),
    // Painel unificado ByVulcan (admin.byvulcan.com) — Cx-1
    VULCAN_ADMIN_URL: z.string().url().optional(),
    VULCAN_PLATFORM_SECRET: z.string().min(16).optional(),
    VULCAN_PRODUCT_ID: z.string().default('vulcan-music'),
});
export const env = Schema.parse(process.env);
//# sourceMappingURL=env.js.map