import { z } from 'zod';
export const StartBodySchema = z.object({
    sessionId: z.string().min(8).optional(),
    client_id: z.string().optional(),
});
export const ApproveBodySchema = z.object({
    user_code: z.string().regex(/^[A-Z0-9-]{4,16}$/),
    user_id: z.string().min(1),
});
export const TokenBodySchema = z.object({
    device_code: z.string().min(16),
});
//# sourceMappingURL=types.js.map