import { describe, it, expect } from 'vitest';
import { buildApp } from '../src/app.js';
import { MemoryStore } from '../src/device-grant/store.js';
describe('GET /health', () => {
    it('returns ok', async () => {
        const app = await buildApp({ deviceGrantStore: new MemoryStore() });
        const res = await app.inject({ method: 'GET', url: '/health' });
        expect(res.statusCode).toBe(200);
        const body = res.json();
        expect(body.status).toBe('ok');
        expect(body.version).toBe('0.1.0');
        await app.close();
    });
});
//# sourceMappingURL=health.test.js.map