import pino from 'pino';
import { env } from './env.js';
const isDev = env.NODE_ENV !== 'production';
export const logger = pino({
    level: env.LOG_LEVEL,
    transport: isDev
        ? { target: 'pino-pretty', options: { colorize: true, translateTime: 'SYS:HH:MM:ss' } }
        : undefined,
});
//# sourceMappingURL=logger.js.map